import java.awt.Color;
import java.awt.GradientPaint;
import java.awt.Paint;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.text.DecimalFormat;

import org.faceless.graph2.*;


public class DialGraphExample {

    /**
     * @param args
     * @throws IOException 
     */
    public static void main(String[] args) throws IOException {
        // Some values we'll be using repeatedly 
        Color fantasticFour = new Color(250,123,213);
        Color batmanBegins = new Color(124,124,255);
        Color hustleFlow = new Color(252,47,110);
        Color marchPenguins = Color.LIGHT_GRAY;
        
        Paint gradient1 = new GradientPaint(75, 75, Color.white, 95, 95, Color.gray, true);
        Paint gradient2 = new GradientPaint(75,75, Color.red, 95, 95, Color.green, true);
        
        DialGraph dgraph1 = new DialGraph();
        dgraph1.setSliceSize(0.5);
        double innerstart = 75, outerstart = 80;
        
        dgraph1.addSegment(-30, 75, innerstart, outerstart, new Style(gradient2));
        dgraph1.addSegment(75, 115, innerstart, outerstart, new Style(Color.BLACK));
        dgraph1.addSegment(115, 180, innerstart, outerstart, new Style(Color.YELLOW));
        dgraph1.addSegment(180, 250, innerstart, outerstart, new Style(Color.GREEN));
        
        dgraph1.addSegment(-30, 250, innerstart-20, outerstart-20, new Style(Color.BLUE));
        dgraph1.addSegment(65, 120, 50, 90, new Style(batmanBegins));
        dgraph1.addSegment(100, 180, 20, 70, new Style(hustleFlow));
        
        // Add some needles
        //dgraph1.addNeedle(30, 0, 0.02, 0.5, 0.05, 0.7, 0.03, marchPenguins, DialGraph.ARROW_LARGE);
        //dgraph1.addNeedle(30, 0, 2, 50, 5, 70, 3, new Style(marchPenguins), DialGraph.ARROW_LARGE);
        dgraph1.addNeedle(30, 0, 2, 50, 5, 70, 3, new Style(gradient1), DialGraph.ARROW_LARGE);
        dgraph1.addNeedle(150, 0, 3, 25, 1, 50, 6, new Style(Color.RED), DialGraph.ARROW_MEDIUM);
        dgraph1.addNeedle(220, 0, 4, 25, 4, 50, 4, new Style(Color.YELLOW), DialGraph.ARROW_NONE);
        
        // Add a small circle at the center
        dgraph1.addSegment(0, 360, 0, 5, new Style(Color.BLACK));
        
        // Add a title
        dgraph1.addText("Here's Some Random Text for Testing", new TextStyle("Default", 22, Color.red, Align.CENTER));
        dgraph1.addText("Some More Random Text", new TextStyle("Default", 18, Color.BLACK, Align.CENTER));
        
        // Add some labels
        Text someText = new Text("This is text", new TextStyle("Courier", 14, Color.GREEN, Align.LEFT));
        dgraph1.addLabel(someText, 270, 120);
        //dgraph1.addLabels(60, 300, 0, 240, 40, 1, false, null, null);
        dgraph1.addLabels(60, 300, 60, 100, false, new TextStyle("Courier", 14, Color.BLACK), null, 0, 240);
        dgraph1.addTicks(60, 300, 60, 95, 100, null);
        
        ImageOutput image = new ImageOutput(500, 500);
        dgraph1.draw(image);
        FileOutputStream out = new FileOutputStream("DialGraphExample1.png");
        image.writePNG(out, 0);
        out.close();
        
        // Another test case
        DialGraph dgraph2 = new DialGraph();
        dgraph2.setSliceSize(0.5);
        double outerstart2 = 65, outerend2 = 100;
        
        // Create the outer segments
        dgraph2.addSegment(0, 180, outerstart2, outerend2, new Style(Color.GRAY));
        dgraph2.addSegment(180, 290, outerstart2, outerend2, new Style(Color.PINK));
        dgraph2.addSegment(290, 360, outerstart2, outerend2, new Style(Color.MAGENTA));
        
        Text total = new Text("Total", new TextStyle("Default", 18, Color.BLACK, Align.CENTER|Align.MIDDLE));
        dgraph2.addLabel(total, 0, 0);
        
        // Label the outer segments
        Text text1 = new Text("C", new TextStyle("Default", 18, Color.BLACK));
        dgraph2.addLabel(text1, 90, (outerstart2+outerend2)/2);
        Text text2 = new Text("A", new TextStyle("Default", 18, Color.BLACK));
        dgraph2.addLabel(text2, 235, (outerstart2+outerend2)/2);
        Text text3 = new Text("B", new TextStyle("Default", 18, Color.BLACK));
        dgraph2.addLabel(text3, 325, (outerstart2+outerend2)/2);
        
        // Create the inner segments
        double innerstart2 = 45, innerend2 = 65;
        dgraph2.addSegment(-20, 70, innerstart2, innerend2, new Style(fantasticFour));
        dgraph2.addSegment(70, 180, innerstart2, innerend2, new Style(batmanBegins));
        dgraph2.addSegment(180, 340, innerstart2, innerend2, new Style(hustleFlow));
        
        // Label the inner segments
        Text text4 = new Text("F", new TextStyle("Default", 18, Color.BLACK));
        dgraph2.addLabel(text4, 25, ((innerstart2+innerend2)/2)-0.1);
        Text text5 = new Text("E", new TextStyle("Default", 18, Color.BLACK));
        dgraph2.addLabel(text5, (70+180)/2, ((innerstart2+innerend2)/2)-0.1);
        Text text6 = new Text("D", new TextStyle("Default", 18, Color.BLACK));
        dgraph2.addLabel(text6, (180+340)/2, ((innerstart2+innerend2)/2)-0.1);
        
        // Add a title
        dgraph2.addText("Title", new TextStyle("Default", 18, Color.BLACK, Align.CENTER));
        
        // Output to a PNG file
        image = new ImageOutput(500,500);
        dgraph2.draw(image);
        FileOutputStream out2 = new FileOutputStream("DialGraphExample2.png");
        image.writePNG(out2, 0);
        out2.close();
        
        // Third test case
        DialGraph dgraph3 = new DialGraph();
        dgraph3.setSliceSize(0.5);
        double innerstart3 = 20, innerend3 = 40;
        double middlestart3 = 40, middleend3 = 90;
        double outerstart3 = 90, outerend3 = 100;
        
        // We add the outer ring first
        dgraph3.addSegment(210, 320, outerstart3, outerend3, new Style(Color.BLACK));
        dgraph3.addSegment(320, 60, outerstart3, outerend3, new Style(Color.GRAY));
        dgraph3.addSegment(60, 150, outerstart3, outerend3, new Style(Color.WHITE));
        
        // Then the middle portion
        dgraph3.addSegment(210, 0, middlestart3, middleend3, new Style(Color.RED));
        dgraph3.addSegment(0, 75, middlestart3, middleend3, new Style(Color.YELLOW));
        dgraph3.addSegment(75, 150, middlestart3, middleend3, new Style(Color.GREEN));
        
        // Then an inner ring
        dgraph3.addSegment(0, 360, innerstart3, innerend3, new Style(Color.WHITE));
        
        //Finally, add a black circle
        dgraph3.addSegment(0, 360, 0, innerstart3, new Style(Color.BLACK));
        
        // Now, add labels around the outer edge of the graph
        //dgraph3.addLabels(-150, 150, 0, 10, 1, outerend3+0.05, true, null, new DecimalFormat("0"));
        dgraph3.addLabels(-150, 150, 30, 110, true, new TextStyle("Courier", 16, Color.BLACK), new DecimalFormat("0"), 0, 10);
        dgraph3.addTicks(-150, 150, 30, outerend3-5, outerend3+5, null);
        
        
        // Output to a PNG file
        image = new ImageOutput(500,500);
        dgraph3.draw(image);
        FileOutputStream out3 = new FileOutputStream("DialGraphExample3.png");
        image.writePNG(out3, 0);
        out3.close();

    }

}
