import org.faceless.graph2.*;
import java.awt.Color;
import java.io.FileOutputStream;
import java.io.IOException;

public class MarkerExample 
{
    public static void main(String args[]) throws IOException
    {
        // Create a new AxesGraph. Set the bottom axis to a MarkerAxis,
        // to display the bar keys as markers
        //
        AxesGraph graph = new AxesGraph(); 
        graph.setAxis(Axis.BOTTOM, new MarkerAxis(20));
        graph.setXRotation(20);
        graph.setYRotation(30);
        
        // Create a new series and set some values on it
        //
        BarSeries series1 = new BarSeries("populations");
        series1.setStyle(new Style(Color.GREEN));
        series1.setBarWidth(0.5);
        series1.setBarDepth(0.8);
        series1.set("flag.UK", 59778002);
        series1.set("flag.AU", 19546792);
        series1.set("flag.NZ", 3908037);
        series1.set("flag.VE", 24287670);
        series1.set("flag.FR", 59765983);
        series1.set("flag.GR", 10645343);
        series1.set("flag.CA", 31902268);
        series1.set("flag.EG", 70712345);
        series1.set("flag.CO", 41008227);
        series1.set("flag.RU", 144978573);
        series1.set("flag.DE", 83251851);
        series1.set("flag.IT", 57715625);
        series1.set("flag.ZA", 43647658);

	graph.addSeries(series1);
        
        // Create a new Key
        //
        Style style = new Style(new Color(249, 218, 232));
        style.setBorderColor(Color.BLACK);
        style.setLineThickness(2);
        Key key = new Key(style);
        
        // Add our flags to the key.
        //
        TextStyle ts = new TextStyle("Comic", 14, Color.BLACK);
        key.addCustom(new Marker("flag.UK", 15), "United Kingdom", ts);
        key.addCustom(new Marker("flag.AU", 15), "Australia", ts);
        key.addCustom(new Marker("flag.NZ", 15), "New Zealand", ts);
        key.addCustom(new Marker("flag.VE", 15), "Venezuela", ts);
        key.addCustom(new Marker("flag.FR", 15), "France", ts);
        key.addCustom(new Marker("flag.GR", 15), "Greece", ts);
        key.addCustom(new Marker("flag.CA", 15), "Canada", ts);
        key.addCustom(new Marker("flag.EG", 15), "Egypt", ts);
        key.addCustom(new Marker("flag.CO", 15), "Colombia", ts);
        key.addCustom(new Marker("flag.RU", 15), "Russian Federation", ts);
        key.addCustom(new Marker("flag.DE", 15), "Germany", ts);
        key.addCustom(new Marker("flag.IT", 15), "Italy", ts);
        key.addCustom(new Marker("flag.ZA", 15), "South Africa", ts);
        graph.addKey(key, Align.RIGHT);
        
        // Set some labels on the X and Y axes
        //
	graph.addText("Populations", new TextStyle("Helvetica", 30, Color.BLUE, Align.CENTER));
        graph.getAxis(Axis.LEFT).setLabel("Number of People", new TextStyle("Times", 12, Color.BLACK));
        graph.getAxis(Axis.BOTTOM).setLabel("Country", new TextStyle("Times", 12, Color.BLACK));
        
        // And finally, write the image out
        //
        ImageOutput image = new ImageOutput(650,500);

        // We used a custom font above, and here's how we'd link that in to a specific
        // AWT font. Commented out so people on UNIX can run this example
        //
        // image.setFont("comic", Font.createFont(Font.TRUETYPE_FONT, new FileInputStream("C:/WINDOWS/Fonts/comic.ttf")));

        graph.draw(image);
	FileOutputStream out = new FileOutputStream("MarkerExample.png");
	image.writePNG(out, 0);
        out.close();
    }
}
