import java.io.StringReader;
import java.net.URL;
import java.util.Iterator;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.soap.AttachmentPart;
import javax.xml.soap.MessageFactory;
import javax.xml.soap.Name;
import javax.xml.soap.Node;
import javax.xml.soap.SOAPBody;
import javax.xml.soap.SOAPConnection;
import javax.xml.soap.SOAPConnectionFactory;
import javax.xml.soap.SOAPElement;
import javax.xml.soap.SOAPHeader;
import javax.xml.soap.SOAPMessage;
import javax.xml.soap.Text;

import org.w3c.dom.Document;
import org.xml.sax.InputSource;

/**
 * A simple example demonstrating how to generate a graph via a SOAP request.
 * This assumes that you have a Servlet environment set up and running on
 * localhost port 8080, and have installed the "bfograph.jar" in that
 * environment as described in the userguide.
 *
 * You will need the java.xml.soap classes from J2EE 1.4 to run this example.
 * Much of the code here is taken from the DOMExample example from the J2EE 1.4
 * tutorial. All we've added is a bit to extract the attachments.
 *
 */
public class SOAPTest
{
    static final String SERVER = "localhost:8080";
    static final String WEBAPP = "";
    static final String FORMAT = "soap-multipart";      // also "soap-html"

    static final String XML= "<bfgsoap:GetHTML xmlns:bfgsoap=\"http://bfo.co.uk/ns/graph/soap?version=2\">" +
                             "<bfg:piegraph xmlns:bfg=\"http://bfo.co.uk/ns/graph?version=2\" height=\"400\" width=\"400\" yrotation=\"-40\" zrotation=\"45\">\n"+
                             "<bfg:label font=\"18pt bold Arial\">My First Pie Graph</bfg:label>\n"+
                             "<bfg:data key=\"apples\" value=\"18\" />\n"+
                             "<bfg:data key=\"oranges\" value=\"22\" />\n"+
                             "</bfg:piegraph></bfgsoap:GetHTML> \n";


    public static void main(String[] args) throws Exception
    {
        SOAPConnectionFactory soapConnectionFactory = SOAPConnectionFactory.newInstance();
        SOAPConnection connection = soapConnectionFactory.createConnection();
        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        factory.setNamespaceAware(true);
        DocumentBuilder builder = factory.newDocumentBuilder();
        Document document = builder.parse(new InputSource(new StringReader(XML)));
        //Document document = builder.parse(new File("graph.soap.xml"));

        MessageFactory messageFactory = MessageFactory.newInstance();
        SOAPMessage message = messageFactory.createMessage();
        SOAPHeader header = message.getSOAPHeader();
        header.detachNode();

        SOAPBody body = message.getSOAPBody();
        body.addDocument(document);
        message.saveChanges();

        URL endpoint = new URL ("http://"+SERVER+"/"+WEBAPP+"/servlet/GraphServlet/"+FORMAT);
        SOAPMessage response = connection.call(message, endpoint);
        connection.close();

        body = response.getSOAPBody();
        Iterator iter1 = body.getChildElements();
        System.out.println("HTML\n---------");
        getContents(iter1, "");

        System.out.println("ATTACHMENT\n---------");
        AttachmentPart a = (AttachmentPart)response.getAttachments().next();
        if (a!=null) {
             String type = a.getContentType();
             Object data = a.getContent();
             System.out.println("TYPE="+type+"\nDATA="+data);
        }
    }

    /*
     * Retrieves the contents of the elements recursively and
     * displays them.
     *
     * @param iterator        Iterator returned by getChildElements
     * @param indent        indentation to nest element display
     */
    public static void getContents(Iterator iterator, String indent)
    {
        while (iterator.hasNext()) {
            Node node = (Node) iterator.next();
            SOAPElement element = null;
            Text text = null;

            if (node instanceof SOAPElement) {
                element = (SOAPElement) node;

                Name name = element.getElementName();
                System.out.println(indent + "Element: " + name.getQualifiedName());

                Iterator attrs = element.getAllAttributes();

                while (attrs.hasNext()) {
                    Name attrName = (Name) attrs.next();
                    System.out.println(indent + "* "+attrName.getQualifiedName()+"="+element.getAttributeValue(attrName));
                }

                Iterator iter2 = element.getChildElements();
                getContents(iter2, indent + " ");
            } else {
                text = (Text) node;

                String content = text.getValue();
                if (content.trim().length()>0) {
                    System.out.println(indent + "Content is: " + content);
                }
            }
        }
    }
}
